col_etree_scratch

Function col_etree_scratch 

pub fn col_etree_scratch<I: Index>(nrows: usize, ncols: usize) -> StackReq
computes the size and alignment of the workspace required to compute the column elimination tree of a matrix $A$ with dimensions (nrows, ncols)