column_counts_aat_scratch

Function column_counts_aat_scratch 

pub fn column_counts_aat_scratch<I: Index>(
    nrows: usize,
    ncols: usize,
) -> StackReq
computes the size and alignment of the workspace required to compute the column counts of the cholesky factor of the matrix $A A^\top$, where $A$ has dimensions (nrows, ncols)