pub fn postorder<I: Index>(
post: &mut [I],
etree: EliminationTreeRef<'_, I>,
stack: &mut MemStack,
)Expand description
computes a postordering of the elimination tree of size n
pub fn postorder<I: Index>(
post: &mut [I],
etree: EliminationTreeRef<'_, I>,
stack: &mut MemStack,
)computes a postordering of the elimination tree of size n