postorder_scratch

Function postorder_scratch 

pub fn postorder_scratch<I: Index>(n: usize) -> StackReq
computes the size and alignment of the workspace required to compute the postordering of an elimination tree of size n