pub struct QrRef<'a, I: Index, T> { /* private fields */ }Expand description
sparse $QR$ factorization wrapper
Implementations
Sourceimpl<'a, I: Index, T> QrRef<'a, I, T>
impl<'a, I: Index, T> QrRef<'a, I, T>
Sourcepub unsafe fn new_unchecked(
symbolic: &'a SymbolicQr<I>,
indices: &'a [I],
val: &'a [T],
) -> Self
pub unsafe fn new_unchecked( symbolic: &'a SymbolicQr<I>, indices: &'a [I], val: &'a [T], ) -> Self
creates a $QR$ decomposition reference from its symbolic and numerical components
safety
the indices must be filled by a previous call to SymbolicQr::factorize_numeric_qr with
the right parameters
Sourcepub fn symbolic(self) -> &'a SymbolicQr<I>
pub fn symbolic(self) -> &'a SymbolicQr<I>
returns the symbolic structure of the $QR$ factorization.
Sourcepub fn solve_in_place_with_conj(
self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
stack: &mut MemStack,
)where
T: ComplexField,
pub fn solve_in_place_with_conj(
self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
stack: &mut MemStack,
)where
T: ComplexField,
solves the equation $A x = \text{rhs}$ in the sense of least squares, implicitly conjugating $A$ if needed
work is a temporary workspace with the same dimensions as rhs