SymbolicQr

Struct SymbolicQr 

pub struct SymbolicQr<I> { /* private fields */ }
the symbolic structure of a sparse $QR$ decomposition

Implementations

Source

impl<I: Index> SymbolicQr<I>

pub fn nrows(&self) -> usize

number of rows of $A$

pub fn ncols(&self) -> usize

number of columns of $A$

pub fn col_perm(&self) -> PermRef<'_, I>

returns the fill-reducing column permutation that was computed during symbolic analysis

pub fn len_idx(&self) -> usize

returns the length of the slice needed to store the symbolic indices of the $QR$ decomposition

pub fn len_val(&self) -> usize

returns the length of the slice needed to store the numerical values of the $QR$ decomposition

pub fn solve_in_place_scratch<T>(&self, rhs_ncols: usize, par: Par) -> StackReq
where T: ComplexField,

returns the size and alignment of the workspace required to solve the system $A x = \text{rhs}$ in the sense of least squares

pub fn factorize_numeric_qr_scratch<T>( &self, par: Par, params: Spec<QrParams, T>, ) -> StackReq
where T: ComplexField,

computes the required workspace size and alignment for a numerical $QR$ factorization

pub fn factorize_numeric_qr<'out, T: ComplexField>( &'out self, indices: &'out mut [I], val: &'out mut [T], A: SparseColMatRef<'_, I, T>, par: Par, stack: &mut MemStack, params: Spec<QrParams, T>, ) -> QrRef<'out, I, T>

computes a numerical $QR$ factorization of $A$