pub struct SymbolicQr<I> { /* private fields */ }Expand description
the symbolic structure of a sparse $QR$ decomposition
Implementations
Sourceimpl<I: Index> SymbolicQr<I>
impl<I: Index> SymbolicQr<I>
Sourcepub fn col_perm(&self) -> PermRef<'_, I>
pub fn col_perm(&self) -> PermRef<'_, I>
returns the fill-reducing column permutation that was computed during symbolic analysis
Sourcepub fn len_idx(&self) -> usize
pub fn len_idx(&self) -> usize
returns the length of the slice needed to store the symbolic indices of the $QR$ decomposition
Sourcepub fn len_val(&self) -> usize
pub fn len_val(&self) -> usize
returns the length of the slice needed to store the numerical values of the $QR$ decomposition
Sourcepub fn solve_in_place_scratch<T>(&self, rhs_ncols: usize, par: Par) -> StackReqwhere
T: ComplexField,
pub fn solve_in_place_scratch<T>(&self, rhs_ncols: usize, par: Par) -> StackReqwhere
T: ComplexField,
returns the size and alignment of the workspace required to solve the system $A x = \text{rhs}$ in the sense of least squares
Sourcepub fn factorize_numeric_qr_scratch<T>(
&self,
par: Par,
params: Spec<QrParams, T>,
) -> StackReqwhere
T: ComplexField,
pub fn factorize_numeric_qr_scratch<T>(
&self,
par: Par,
params: Spec<QrParams, T>,
) -> StackReqwhere
T: ComplexField,
computes the required workspace size and alignment for a numerical $QR$ factorization
Sourcepub fn factorize_numeric_qr<'out, T: ComplexField>(
&'out self,
indices: &'out mut [I],
val: &'out mut [T],
A: SparseColMatRef<'_, I, T>,
par: Par,
stack: &mut MemStack,
params: Spec<QrParams, T>,
) -> QrRef<'out, I, T>
pub fn factorize_numeric_qr<'out, T: ComplexField>( &'out self, indices: &'out mut [I], val: &'out mut [T], A: SparseColMatRef<'_, I, T>, par: Par, stack: &mut MemStack, params: Spec<QrParams, T>, ) -> QrRef<'out, I, T>
computes a numerical $QR$ factorization of $A$